xsdata.formats.dataclass.models.constants module
================================================

.. automodule:: xsdata.formats.dataclass.models.constants
   :members:
   :undoc-members:
   :show-inheritance:
